@@ -1,4 +1,5 @@
-from version import (__version__, __author__, __upgrade_date__, __name__, __email__, __doc_format__)
+from __future__ import absolute_import
+from bioat.version import (__version__, __author__, __upgrade_date__, __name__, __email__, __doc_format__)
 
 about = f"""
 BioinformaticAnalysisTools ({__name__})
