@@ -1,11 +1,6 @@
+from __future__ import absolute_import
 import fire
-from version import (__version__, __author__, __upgrade_date__, __email__, __doc_format__)
-from about import about
-from fastx import Fastx
-from table import Table
-from hic import HiC
-from mgi import Mgi
-from system import System
+from bioat import about, Bam, Fastx, HiC, Mgi, System, Table, __version__
 
 
 class Cli(object):
@@ -18,19 +13,33 @@ class Cli(object):
     """
 
     def __init__(self):
-        self.fastx = Fastx()
+        self.bam = Bam()
+        # self.fastx = Fastx()
         self.hic = HiC()
         self.mgi = Mgi()
-        self.system = System()
+        # self.system = System()
         self.table = Table()
 
     def about(self):
-        """Print information about <bioat>
+        """Print information about <bioat>.
         """
         return about
 
     def list(self):
-        return "all cmds"
+        """Print commands and subcommands.
+        """
+        for att in dir(self):
+            if not att.startswith('_'):
+                print(f'{att}')
+
+                for sub_att in dir(getattr(self, att)):
+                    if not sub_att.startswith('_'):
+                        print(f'  ├── {sub_att}')
+
+    def version(self):
+        """Print version information.
+        """
+        return __version__
 
 
 def main() -> int:
